@@ -141,7 +141,7 @@ sub source {
     my $processable = $self->processable;
     my $group = $self->group;
 
-    my $debian_dir = $processable->index_resolved_path('debian');
+    my $debian_dir = $processable->patched->resolve_path('debian');
     my $rules;
     $rules = $debian_dir->child('rules') if $debian_dir;
 
@@ -172,8 +172,7 @@ sub source {
       unless $start =~ m%^\#!\s*/usr/bin/make\s+-[re]?f[re]?\s*$%;
 
     # Check if debian/rules is marked as executable.
-    $self->tag('debian-rules-not-executable')
-      unless $rules->operm == 0755 or $rules->is_symlink;
+    $self->tag('debian-rules-not-executable') unless $rules->is_executable;
 
     # Holds which dependencies are required.  The keys in %needed and
     # %needed_clean are the dependencies; the values are the tags to use or the
