@@ -62,7 +62,7 @@ sub source {
     my $format = $processable->field('format', '');
     my $quilt_format = ($format =~ /3\.\d+ \(quilt\)/) ? 1 : 0;
 
-    my $droot = $processable->index_resolved_path('debian/');
+    my $droot = $processable->patched->resolve_path('debian/');
     return if not $droot;
     my $dpdir = $droot->resolve_path('patches');
     my $patch_series;
@@ -313,7 +313,7 @@ sub check_patch {
         my $tag_emitter
           = $self->spelling_tag_emitter('spelling-error-in-patch-description',
             $patch_file);
-        check_spelling($description, $group->info->spelling_exceptions,
+        check_spelling($description, $group->spelling_exceptions,
             $tag_emitter, 0);
     }
     # Use --strip=1 to strip off the first layer of directory in case
