@@ -36,11 +36,10 @@ sub binary {
 
     my $pkg = $self->package;
     my $type = $self->type;
-    my $info = $self->info;
-    my $proc = $self->processable;
+    my $processable = $self->processable;
     my $group = $self->group;
 
-    my $rules_dir = $info->index_resolved_path('lib/udev/rules.d/');
+    my $rules_dir = $processable->installed->resolve_path('lib/udev/rules.d/');
     return unless $rules_dir;
     foreach my $file ($rules_dir->children) {
         if (!$file->is_open_ok) {
@@ -127,6 +126,19 @@ sub check_udev_rules {
     return $retval;
 }
 
+sub files {
+    my ($self, $file) = @_;
+
+    return
+      unless $file->name =~ m,^etc/udev/,;
+
+    # /etc/udev/rules.d
+    $self->tag('udev-rule-in-etc', $file->name)
+      if $file->name =~ m,^etc/udev/rules\.d/\S,;
+
+    return;
+}
+
 1;
 
 # Local Variables:
