@@ -27,6 +27,7 @@ use autodie qw(opendir closedir);
 
 use Carp qw(croak);
 use File::Find::Rule;
+use Path::Tiny;
 
 use Dpkg::Vendor qw(get_current_vendor get_vendor_info);
 
@@ -133,6 +134,8 @@ sub new {
         'check-tagnames'       => {},
         # maps tag name to Lintian::Tag::Info
         'known-tags'           => {},
+        # maps old tag names to new tag names
+        'renamed-tags'         => {},
     };
     $self = bless $self, $type;
     if (not defined $name) {
@@ -168,6 +171,15 @@ sub new {
                     $taginfo->tag
                 );
             }
+
+            for my $alias ($taginfo->aliases) {
+                my $taken = $self->{'renamed-tags'}{$alias};
+                die "Internal error: tags $taken and "
+                  . $taginfo->tag
+                  . " share same alias $alias."
+                  if defined $taken;
+                $self->{'renamed-tags'}{$alias} = $taginfo->tag;
+            }
         }
     }
 
@@ -217,6 +229,17 @@ sub tags {
     return keys %{ $self->{'enabled-tags'} };
 }
 
+=item $prof->aliases()
+
+Returns a hash with old names that have new names.
+
+=cut
+
+sub aliases {
+    my ($self) = @_;
+    return $self->{'renamed-tags'};
+}
+
 =item $prof->scripts ([$known])
 
 Returns the list of Check-Scripts in this profile.  If $known
@@ -373,12 +396,12 @@ sub _find_profile {
 # normally, the profile will have been parsed successfully.
 sub _read_profile {
     my ($self, $pfile) = @_;
-    my @pdata;
     my $pheader;
     my $pmap = $self->{'parent-map'};
     my $pname;
     my $plist = $self->{'profile_list'};
-    @pdata = read_dpkg_control_utf8($pfile, 0);
+    my @dirty = read_dpkg_control_utf8($pfile, 0);
+    my @pdata = _clean_fields(@dirty);
     $pheader = shift @pdata;
     croak "Profile field is missing from $pfile"
       unless defined $pheader && $pheader->{'profile'};
@@ -419,6 +442,35 @@ sub _read_profile {
     return;
 }
 
+# $self->_clean_fields(@dirty)
+#
+# Cleans the paragraphs from read_dpkg_control
+sub _clean_fields {
+    my @dirty = @_;
+
+    my @clean;
+
+    foreach my $paragraphref (@dirty) {
+        my %paragraph = %{$paragraphref};
+
+        foreach my $field (keys %paragraph) {
+
+            # unwrap continuation lines
+            $paragraph{$field} =~ s/\n/ /g;
+
+            # trim both ends
+            $paragraph{$field} =~ s/^\s+|\s+$//g;
+
+            # reduce multiple spaces to one
+            $paragraph{$field} =~ s/\s+/ /g;
+        }
+
+        push(@clean, \%paragraph);
+    }
+
+    return @clean;
+}
+
 # $self->_read_profile_section($pname, $section, $sno)
 #
 # Parses and applies the effects of $section (a paragraph
@@ -620,7 +672,10 @@ sub _load_check {
             last;
         }
     }
-    croak "$profile references unknown check $check" unless defined $dir;
+
+    croak "Profile $profile references unknown check $check"
+      unless defined $dir;
+
     return $self->_parse_check($check, $dir);
 }
 
@@ -660,15 +715,15 @@ sub _load_checks {
     my ($self) = @_;
     foreach my $checkdir ($self->_safe_include_path('checks')) {
         next unless -d $checkdir;
-        opendir(my $dirfd, $checkdir);
-        for my $desc (sort readdir $dirfd) {
-            my $cname = $desc;
-            next unless $cname =~ s/\.desc$//o;
-            # _parse_check ignores duplicates, so we don't have to
-            # check for it.
-            $self->_parse_check($cname, $checkdir);
+
+        my @descpaths
+          = sort File::Find::Rule->file->name('*.desc')->in($checkdir);
+        for my $desc (@descpaths) {
+            my $relative = path($desc)->relative($checkdir)->stringify;
+            my ($name) = ($relative =~ qr/^(.*)\.desc$/);
+            # _parse_check ignores duplicates on its own
+            $self->_parse_check($name, $checkdir);
         }
-        closedir($dirfd);
     }
     return;
 }
